;;;-*- Mode: Lisp; -*-
;;; YstokGrid - LispWorks CAPI-based grid widget
;;; Copyright (c) 2003-2013 Dr. Dmitry Ivanov. All rights reserved.
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; LW System definition

(in-package :cl-user)

#-(and lispworks capi) (error "This code can only run on LispWorks CAPI.")

(require "selection-mode")

;(pushnew :debug *features*)
;(removef *features* :debug)
;(yl:debug-on :grid) (yl:debug-off :grid)
;(pushnew :Russian *features*)
;(pushnew :ys-product *features*)
;(load #P"PROJECTS:ylib;defsys")
;(compile-system 'YSTOK-LIBRARY :load t)
;;(load #P"PROJECTS:ylib;local-time;defsys")
;;(compile-system 'LOCAL-TIME :load t)
;(load #P"PROJECTS:ywidgets;defsys")
;(compile-system 'YWIDGETS :load t)

(defsystem YGRID (:object-pathname (lw:current-pathname
       	#+(not (or Russian German debug))		"bin/"
	#+(and (not Russian) (not German) debug)	"bin/debug/"
	#+(and Russian (not debug))			"bin/ru/"
	#+(and Russian debug)				"bin/debug/ru/"
	#+(and German (not debug))			"bin/de/"
	#+(and German debug)				"bin/debug/de/"))
 :members
 ((YSTOK-LIBRARY :type :system)
  (YWIDGETS	 :type :system)
  (LOCAL-TIME	 :type :system  :features :local-time)
  "grid-package"
  ("lang/ru"			:features :Russian)
  "basics"
  "core"
  "pinboard"
  "column-header"
  "row-header"
  "check-column"
  "text-column"
  ("lang/product-ru"		:features (and :ys-product :Russian))
  ("buttoned-column"		:features :ys-product)
  ("popup-column"		:features :ys-product)
  ("editing-pane-column"	:features :ys-product)
  "utils"
  "sorted-grid"
  "searcher"
  "toolbars"
  ("ys-product"			:features :ys-product)
  ("grid-local-time"		:features (and :ys-product :local-time))
  ("record-clipboard" 		:features :ys-product)
  ("zoom"	 		:features :ys-product)
  ("menus"			:features :ys-product)
  ("datasheet" 			:features :ys-product)
  ("formulary" 			:features :ys-product)
 )
 :rules
 ((:in-order-to :compile "grid-package" ;(:caused-by(:compile YSTOK-LIBRARY YSTOK-WIDGETS))
   (:requires (:load YSTOK-LIBRARY YWIDGETS)))
  (:in-order-to :load "grid-package"
   (:requires (:load YSTOK-LIBRARY YWIDGETS)))

  (:in-order-to :compile ("ru" "product-ru")
   (:requires (:load "grid-package")))
  (:in-order-to :load ("ru" "product-ru")
   (:requires (:load "grid-package")))

  (:in-order-to :compile "basics" (:caused-by (:compile "grid-package" "ru"))
   (:requires (:load "grid-package" "ru")))
  (:in-order-to :load "basics"
   (:requires (:load "grid-package" "ru"))) 

  (:in-order-to :compile "core" (:caused-by (:compile "basics"))
   (:requires (:load "basics")))
  (:in-order-to :load "core"
   (:requires (:load "basics")))

  (:in-order-to :compile ("pinboard"
                          "column-header" "row-header"
                          "check-column" "text-column" "popup-column"
                          "utils")
   (:caused-by (:compile "core"))
   (:requires (:load "core")))
  (:in-order-to :load ("pinboard"
                       "column-header" "row-header"
                       "check-column" "text-column" "popup-column"
                       "utils")
   (:caused-by (:load "basics"))
   (:requires (:load "core")))

  (:in-order-to :compile "buttoned-column" (:caused-by (:compile "text-column"))
   (:requires (:load "text-column")))
  (:in-order-to :load "buttoned-column"
   (:requires (:load "text-column")))

  (:in-order-to :compile "popup-column" (:caused-by (:compile "buttoned-column"))
   (:requires (:load "product-ru" "buttoned-column"))
   (:caused-by (:load "product-ru")))
  (:in-order-to :load "popup-column"
   (:requires (:load "product-ru" "buttoned-column")))

  (:in-order-to :compile "editing-pane-column" (:caused-by (:compile "popup-column"))
   (:requires (:load  "popup-column")))
  (:in-order-to :load "editing-pane-column"
   (:requires (:load  "popup-column")))

  (:in-order-to :compile ("sorted-grid" "searcher")
   (:requires (:load "column-header" "row-header" "check-column" "text-column")))
  (:in-order-to :load ("sorted-grid" "searcher")
   (:requires (:load "column-header" "row-header" "check-column" "text-column")))

  (:in-order-to :compile "toolbars"
   (:requires (:load "sorted-grid" "searcher")))
  (:in-order-to :load "toolbars"
   (:requires (:load "sorted-grid" "searcher")))

  (:in-order-to :compile "ys-product"
   (:caused-by (:compile "column-header" "row-header" "check-column"
                         "text-column" "popup-column" "editing-pane-column" 
                         "product-ru"
                         #+local-time LOCAL-TIME))
   (:requires (:load "product-ru" "sorted-grid" "searcher")))
  (:in-order-to :load "ys-product"
   (:caused-by (:load "grid-package" "basics" "column-header" "row-header" "product-ru"))
   (:requires (:load "sorted-grid" "searcher" "product-ru")))

  (:in-order-to :compile "grid-local-time" (:caused-by (:compile "popup-column"))
   (:requires (:load "popup-column" #+local-time LOCAL-TIME)))
  (:in-order-to :load "grid-local-time"
   (:requires (:load "popup-column" #+local-time LOCAL-TIME)))

  (:in-order-to :compile ("record-clipboard" "zoom")
   (:requires (:load "toolbars" "product-ru" "popup-column")))
  (:in-order-to :load ("record-clipboard" "zoom")
   (:caused-by (:load "grid-package"))
   (:requires (:load "toolbars" "product-ru" "popup-column")))

  (:in-order-to :compile "menus"
   (:requires (:load "product-ru" "record-clipboard" "zoom")))
  (:in-order-to :load "menus"
   (:caused-by (:load "grid-package" "pinboard"))
   (:requires (:load "product-ru" "record-clipboard")))

  (:in-order-to :compile "datasheet"
   (:requires (:load "toolbars" "ys-product")))
  (:in-order-to :load "datasheet"
   (:caused-by (:load "grid-package"))
   (:requires (:load "toolbars" "ys-product")))

  (:in-order-to :compile "formulary"
   (:requires (:load "datasheet")))
  (:in-order-to :load "formulary"
   (:caused-by (:load "grid-package"))
   (:requires (:load "datasheet")))
))

#+ys-product
(ys:defmodule :ygrid (1 0 :abbrev "gri") :depends-on (:ylib :ywidgets))

;(compile-system 'YGRID :load t)

